launch_offscreen

Function launch_offscreen 

pub fn launch_offscreen(
    spec: &LaunchSpec,
) -> Result<OffscreenLaunch, OffscreenError>
Spawn the app with off-screen mode requested and wait for its session report. Verifies the reported PID is the spawned child and (macOS) that the reported window id exists and belongs to that PID.